"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactHelmet = require("react-helmet");
var _reactIntl = require("react-intl");
var _passwordHelpers = require("../../../helpers/passwordHelpers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); } /* global window, btoa, FormData */
const messages = (0, _reactIntl.defineMessages)({
  title: {
    "id": "passwordResetPage.title",
    "defaultMessage": "Reset Password"
  },
  prompt: {
    "id": "passwordResetPage.prompt",
    "defaultMessage": "Enter the new password for this account."
  },
  password: {
    "id": "passwordResetPage.password",
    "defaultMessage": "Password"
  },
  confirmPassword: {
    "id": "passwordResetPage.confirmPassword",
    "defaultMessage": "Confirm password"
  },
  submit: {
    "id": "passwordResetPage.submit",
    "defaultMessage": "Submit"
  },
  errorMissingPassword: {
    "id": "passwordResetPage.errorMissingPassword",
    "defaultMessage": "Please enter a new password."
  },
  errorNotConfirmed: {
    "id": "passwordResetPage.errorNotConfirmed",
    "defaultMessage": "The password was not correctly confirmed. Please re-enter the new password in the confirm password field."
  },
  errorInvalidPassword: {
    "id": "passwordResetPage.errorInvalidPassword",
    "defaultMessage": "The password must be between 8 and 24 characters."
  },
  success: {
    "id": "passwordResetPage.success",
    "defaultMessage": "Your password has been reset. {loginLink} to continue."
  },
  loginLink: {
    "id": "passwordResetPage.loginLink",
    "defaultMessage": "Sign in"
  },
  newRequestLink: {
    "id": "passwordResetPage.newRequestLink",
    "defaultMessage": "make a new request"
  },
  error: {
    "id": "passwordResetPage.error",
    "defaultMessage": "An error occurred while attempting to reset the password: {detail}"
  },
  errorTokenExpired: {
    "id": "passwordResetPage.errorTokenExpired",
    "defaultMessage": "The password reset request has expired. Please {newRequestLink} to reset your password."
  },
  errorTokenInvalid: {
    "id": "passwordResetPage.errorTokenInvalid",
    "defaultMessage": "The password reset request could not be validated. Please {newRequestLink} to reset your password."
  }
});
const propTypes = {
  csrf: _propTypes.default.object,
  intl: _reactIntl.intlShape.isRequired,
  tenantId: _propTypes.default.string,
  token: _propTypes.default.string.isRequired
};
const defaultProps = {
  csrf: null,
  tenantId: null
};
function PasswordResetPage(props) {
  const {
    csrf,
    intl,
    tenantId,
    token
  } = props;
  const [error, setError] = (0, _react.useState)();
  const [isPending, setPending] = (0, _react.useState)();
  const [success, setSuccess] = (0, _react.useState)();
  if (success) {
    return /*#__PURE__*/_react.default.createElement("p", {
      className: "status success"
    }, success);
  }
  const handleSubmit = event => {
    event.preventDefault();
    const form = event.target;
    const formData = new FormData(form);
    const password = formData.get('password');
    const confirmPassword = formData.get('confirmPassword');
    if (!password) {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.errorMissingPassword));
      return;
    }
    if (!(0, _passwordHelpers.isValidPassword)(password)) {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.errorInvalidPassword));
      return;
    }
    if (password !== confirmPassword) {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.errorNotConfirmed));
      return;
    }
    const url = new URL(form.action);
    const params = url.searchParams;
    params.delete('token');
    if (csrf) {
      params.set(csrf.parameterName, csrf.token);
    }
    const payload = {
      'ns2:passwordreset': {
        '@xmlns:ns2': 'http://collectionspace.org/services/authentication',
        token,
        password: btoa(password)
      }
    };
    setError(null);
    setPending(true);
    window.fetch(url, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(payload)
    }).then(response => Promise.all([response, response.text()])).then(([response, text]) => {
      if (response.ok) {
        setError(null);
        const loginLink = /*#__PURE__*/_react.default.createElement("a", {
          href: "../login"
        }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.loginLink));
        setSuccess( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.success, {
          values: {
            loginLink
          }
        })));
      } else {
        setSuccess(null);
        const {
          status
        } = response;
        const tidParam = tenantId ? `?tid=${tenantId}` : '';
        const values = {
          detail: text,
          newRequestLink: /*#__PURE__*/_react.default.createElement("a", {
            href: `./requestpasswordreset${tidParam}`
          }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.newRequestLink))
        };
        let message = null;
        if (status === 400 || status === 500) {
          if (/token .* not valid/.test(text)) {
            message = messages.errorTokenInvalid;
          } else if (/token .* expired/.test(text)) {
            message = messages.errorTokenExpired;
          }
        }
        if (!message) {
          message = messages.error;
        }
        setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, message, {
          values: values
        })));
      }
    }).catch(err => {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.error, {
        values: {
          detail: err.message
        }
      })));
    }).finally(() => {
      setPending(false);
    });
  };
  const errorMessage = error ? /*#__PURE__*/_react.default.createElement("p", {
    className: "status error"
  }, error) : undefined;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactHelmet.Helmet, null, /*#__PURE__*/_react.default.createElement("title", null, intl.formatMessage(messages.title))), errorMessage, /*#__PURE__*/_react.default.createElement("main", null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.prompt)), /*#__PURE__*/_react.default.createElement("form", {
    method: "POST",
    onSubmit: handleSubmit
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("label", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.password), /*#__PURE__*/_react.default.createElement("input", {
    autoComplete: "new-password",
    name: "password",
    type: "password"
  }))), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("label", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.confirmPassword), /*#__PURE__*/_react.default.createElement("input", {
    autoComplete: "new-password",
    name: "confirmPassword",
    type: "password"
  }))), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("button", {
    className: "reset",
    disabled: isPending,
    type: "submit"
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.submit))))));
}
PasswordResetPage.propTypes = propTypes;
PasswordResetPage.defaultProps = defaultProps;
var _default = (0, _reactIntl.injectIntl)(PasswordResetPage);
exports.default = _default;